=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-12-25 00:38:48 +0000
+++ bzrlib/branch.py	2005-12-25 22:44:53 +0000
@@ -558,9 +558,13 @@
         ]
         cfn = self.control_files._rel_controlfilename
         self.control_files._transport.mkdir_multi([cfn(d) for d in dirs])
-        for file, content in files:
-            self.control_files.put_utf8(file, content)
-        mutter('created control directory in ' + self.base)
+        self.control_files.lock_write()
+        try:
+            for file, content in files:
+                self.control_files.put_utf8(file, content)
+            mutter('created control directory in ' + self.base)
+        finally:
+            self.control_files.unlock()
 
     def _check_format(self, relax_version_check):
         """Check this branch format is supported.

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-12-25 00:38:48 +0000
+++ bzrlib/builtins.py	2005-12-25 22:44:53 +0000
@@ -602,7 +602,12 @@
             branch = Branch.open(to_location)
             if name:
                 name = StringIO(name)
-                branch.control_files.put_utf8('branch-name', name)
+                branch.lock_write()
+                try:
+                    branch.control_files.put_utf8('branch-name', name)
+                finally:
+                    branch.unlock()
+                    
             note('Branched %d revision(s).' % branch.revno())
         finally:
             br_from.unlock()

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2005-12-25 00:38:48 +0000
+++ bzrlib/tests/test_inv.py	2005-12-25 22:44:53 +0000
@@ -335,7 +335,11 @@
         self.wt.add(['file'], ['fileid'])
         self.wt.commit('add file', rev_id='B')
         self.inv_B = self.branch.repository.get_inventory('B')
-        self.branch.control_files.put_utf8('revision-history', 'A\n')
+        self.branch.lock_write()
+        try:
+            self.branch.control_files.put_utf8('revision-history', 'A\n')
+        finally:
+            self.branch.unlock()
         self.assertEqual(self.branch.revision_history(), ['A'])
         self.wt.commit('another add of file', rev_id='C')
         self.inv_C = self.branch.repository.get_inventory('C')

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2005-12-25 00:38:48 +0000
+++ bzrlib/upgrade.py	2005-12-25 22:44:53 +0000
@@ -102,11 +102,19 @@
         self.pb = ui_factory.progress_bar()
         if self.old_format == 4:
             note('starting upgrade from format 4 to 5')
-            self._convert_to_weaves()
+            self.branch.lock_write()
+            try:
+                self._convert_to_weaves()
+            finally:
+                self.branch.unlock()
             self._open_branch()
         if self.old_format == 5:
             note('starting upgrade from format 5 to 6')
-            self._convert_to_prefixed()
+            self.branch.lock_write()
+            try:
+                self._convert_to_prefixed()
+            finally:
+                self.branch.unlock()
             self._open_branch()
         cache = hashcache.HashCache(os.path.abspath(self.base))
         cache.clear()

